complete --keep-order --exclusive --command slumber --arguments "(COMPLETE=fish /build/slumber/src/slumber-5.3.0/target/release/slumber -- (commandline --current-process --tokenize --cut-at-cursor) (commandline --current-token))"
